pub fn compare_c_str<A: AsRef<CStr>, B: AsRef<CStr>>(a: A, b: B) -> OrderingAvailable on crate feature
std only.Expand description
Compare two CStr.
The alphanumeric algorithm is used only when both values can be converted to UTF-8
with CStr::to_str. If either value cannot be converted, this falls back to the
native CStr ordering.