compare_path

Function compare_path 

pub fn compare_path<A: AsRef<Path>, B: AsRef<Path>>(a: A, b: B) -> Ordering
Available on crate feature std only.
Compare two Path.

The alphanumeric algorithm is used only when both paths can be converted to UTF-8 through their OsStr representations. If either path cannot be converted, this falls back to the native OsStr ordering.