sort_c_str_slice

Function sort_c_str_slice 

pub fn sort_c_str_slice<S: AsRef<CStr>>(slice: &mut [S])
Available on crate feature std only.
Sort a CStr slice.

The alphanumeric algorithm is used only if every item can be converted to UTF-8. If any item cannot be converted, the whole slice is sorted by native CStr ordering.