pub fn sort_os_str_slice<S: AsRef<OsStr>>(slice: &mut [S])Available on crate feature
std only.Expand description
Sort an OsStr slice.
The alphanumeric algorithm is used only if every item can be converted to UTF-8.
If any item cannot be converted, the whole slice is sorted by native OsStr
ordering.