sort_os_str_slice_rev

Function sort_os_str_slice_rev 

pub fn sort_os_str_slice_rev<S: AsRef<OsStr>>(slice: &mut [S])
Available on crate feature std only.
Reversely sort an OsStr slice.

The alphanumeric algorithm is used only if every item can be converted to UTF-8. If any item cannot be converted, the whole slice is sorted by native OsStr ordering.