sort_path_slice

Function sort_path_slice 

pub fn sort_path_slice<P: AsRef<Path>>(slice: &mut [P])
Available on crate feature std only.
Sort a Path slice.

The alphanumeric algorithm is used only if every item can be converted to UTF-8 through its OsStr representation. If any item cannot be converted, the whole slice is sorted by native OsStr ordering.