sort_path_slice_rev

Function sort_path_slice_rev 

pub fn sort_path_slice_rev<P: AsRef<Path>>(slice: &mut [P])
Available on crate feature std only.
Reversely sort a Path slice.

The alphanumeric algorithm is used only if every item can be converted to UTF-8 through its OsStr representation. If any item cannot be converted, the whole slice is sorted by native OsStr ordering.