sort_slice_by_path_key

Function sort_slice_by_path_key 

pub fn sort_slice_by_path_key<A, T: ?Sized + AsRef<Path>, F: FnMut(&A) -> &T>(
    slice: &mut [A],
    f: F,
)
Available on crate feature std only.
Sort a slice by a Path key.

The alphanumeric algorithm is used only if every key can be converted to UTF-8 through its OsStr representation. If any key cannot be converted, the whole slice is sorted by native OsStr key ordering.