pub fn sort_c_str_slice_rev<S: AsRef<CStr>>(slice: &mut [S])Available on crate feature
std only.Expand description
Reversely sort a CStr slice.
The alphanumeric algorithm is used only if every item can be converted to UTF-8.
If any item cannot be converted, the whole slice is sorted by native CStr
ordering.